@@ -49,7 +49,6 @@ fabR_help <- function(){
 #' }
 #'
 #' @import dplyr
-#' @importFrom magrittr %>%
 #' @importFrom rlang .data
 #' @export
 message_on_prompt <- function(...){
@@ -83,7 +82,6 @@ message_on_prompt <- function(...){
 #' }
 #'
 #' @import dplyr
-#' @importFrom magrittr %>%
 #' @importFrom rlang .data
 #' @export
 silently_run <- function(...){
@@ -157,7 +155,6 @@ silently_run <- function(...){
 #' }
 #'
 #' @import dplyr
-#' @importFrom magrittr %>%
 #' @importFrom rlang .data
 #' @export
 parceval <- function(...){
@@ -192,7 +189,6 @@ parceval <- function(...){
 #' }
 #'
 #' @import dplyr
-#' @importFrom magrittr %>%
 #' @importFrom rlang .data
 #' @export
 read_excel_allsheets <- function(filename, sheets = "") {
@@ -253,7 +249,6 @@ read_excel_allsheets <- function(filename, sheets = "") {
 #' }
 #'
 #' @import dplyr
-#' @importFrom magrittr %>%
 #' @importFrom rlang .data
 #' @export
 write_excel_allsheets <- function(list, filename){
@@ -295,8 +290,6 @@ write_excel_allsheets <- function(list, filename){
 #' try(read_csv_any_formats(filename = tempfile()),silent = TRUE)
 #'
 #' }
-#'
-#' @importFrom magrittr %>%
 #' @importFrom rlang .data
 #' @export
 read_csv_any_formats <- function(filename){
@@ -329,17 +322,28 @@ read_csv_any_formats <- function(filename){
 #' @examples
 #' {
 #'
+#' ##### Example 1 -------------------------------------------------------------
+#' # add an index for the tibble
 #' add_index(iris, "my_index")
 #'
+#' ##### Example 2 -------------------------------------------------------------
+#' # add an index for the grouped tibble
+#' library(tidyr)
+#' library(dplyr)
+#'
+#' my_tbl <- tibble(iris) %>% group_by(Species) %>% slice(1:3)
+#' fabR::add_index(my_tbl, "my_index")
+#'
 #' }
 #'
 #' @import dplyr
-#' @importFrom magrittr %>%
 #' @importFrom rlang .data
 #'
 #' @export
 add_index <- function(tbl, name_index = "index", start = 1, .force = FALSE){
 
+  class_tbl <- toString(class(tbl))
+  group_name <- group_vars(tbl)
 
   tbl_index <-
     data.frame(index = NA_integer_) %>%
@@ -351,16 +355,18 @@ add_index <- function(tbl, name_index = "index", start = 1, .force = FALSE){
       stop(paste0("\n\nThe column ",name_index," already exists.\n",
                   "Please specifie another name or use .force = TRUE\n"))}
 
-    tbl <-
-      bind_cols(tbl_index,tbl) %>%
-      mutate(across(all_of(name_index), ~ as.integer(row_number() + start - 1)))
-  }
+    tbl <- suppressMessages(bind_cols(tbl_index,tbl))
+  }else{
+    tbl <- suppressMessages(bind_cols(tbl_index,tbl %>%
+                                        select(-any_of(name_index))))}
 
-  if(.force == TRUE){
-    tbl <-
-      bind_cols(tbl_index,tbl %>% select(-any_of(name_index))) %>%
-      mutate(across(all_of(name_index), ~ as.integer(row_number() + start - 1)))
-  }
+
+  if(length(group_name)) tbl <- group_by_at(tbl, group_name)
+
+  tbl <- tbl %>% mutate(across(all_of(name_index),
+                               ~ as.integer(row_number() + start - 1)))
+
+  if(stringr::str_detect(class_tbl,"tbl")) tbl <- tibble(tbl)
 
   return(tbl)
 }
@@ -397,7 +403,6 @@ add_index <- function(tbl, name_index = "index", start = 1, .force = FALSE){
 #' }
 #'
 #' @import dplyr
-#' @importFrom magrittr %>%
 #' @importFrom rlang .data
 #' @export
 get_path_list <- function(list_obj, .map_list = NULL){
@@ -482,7 +487,6 @@ get_path_list <- function(list_obj, .map_list = NULL){
 #' {
 #'
 #' library(tidyr)
-#' library(magrittr)
 #'
 #' #### Example 1 --------------------------------------------------------------
 #' # make_name_list generates names that are informative through a line of code
@@ -513,7 +517,6 @@ get_path_list <- function(list_obj, .map_list = NULL){
 #' }
 #'
 #' @import dplyr
-#' @importFrom magrittr %>%
 #' @importFrom rlang .data
 #' @export
 make_name_list <- function(args_list, list_elem){
@@ -583,14 +586,14 @@ Please verify the names of your elements and reparse.\n", call. = FALSE)
 #' }
 #'
 #' @import dplyr stringr
-#' @importFrom magrittr %>%
 #' @importFrom rlang .data
 #'
 #' @export
 as_any_boolean <- function(x){
 
-  if(length(x) == 0) return(as.logical(x))
-  if(typeof(x) == "logical") return(x)
+  if(length(x)     == 0)         return(as.logical(x))
+  if(all(is.na(x)))              return(as.logical(x))
+  if(typeof(x)     == "logical") return(x)
 
   # check if the col is empty
   if(is.list(x) & nrow(x) %>% sum <= 1){ return(as_any_boolean(x = x[[1]])) }
@@ -600,26 +603,27 @@ as_any_boolean <- function(x){
 
   x <- str_squish(x)
 
-  xtemp <- x
-  for(i in seq_len(length(x))){
+  xtemp <- tibble(x = unique(x), xtemp = unique(x))
+  for(i in seq_len(nrow(xtemp))){
     # stop()}
 
-    xtemp[i] <-
-      suppressWarnings(suppressMessages(try({
-        case_when(
-          is.na(x[i])                                          ~ NA_character_,
-          toString(tolower(x[i]))   %in% c("1", "t","true")    ~ "TRUE" ,
-          toString(as.numeric(x[i])) ==    "1"                 ~ "TRUE",
-          toString(tolower(x[i]))   %in% c("0", "f","false")   ~ "FALSE",
-          toString(as.numeric(x[i])) ==    "0"                 ~ "FALSE",
-          TRUE                                                 ~ "NaN")
+    if(is.na(xtemp$xtemp[i]))
+      xtemp$xtemp[i] <- NA_character_ else
+    if(toString(tolower(xtemp$xtemp[i])) %in% c("1","t","true"))
+      xtemp$xtemp[i] <- "TRUE" else
+    if(silently_run(toString(as.numeric(xtemp$xtemp[i]))) == "1")
+      xtemp$xtemp[i] <- "TRUE" else
+    if(toString(tolower(xtemp$xtemp[i])) %in% c("0", "f","false"))
+      xtemp$xtemp[i] <- "FALSE" else
+    if(silently_run(toString(as.numeric(xtemp$xtemp[i]))) == "0")
+      xtemp$xtemp[i] <- "FALSE" else xtemp$xtemp[i] <- "NaN"
 
-      }, silent = TRUE)))
-
-    if(toString(xtemp[i]) == "NaN")
+    if(toString(xtemp$xtemp[i]) == "NaN")
       stop("x is not in a standard unambiguous format")
   }
 
+  xtemp <- tibble(x = x) %>% left_join(xtemp,by = 'x') %>% pull('xtemp')
+
   x <- as.logical(xtemp)
   return(x)
 }
@@ -646,7 +650,6 @@ as_any_boolean <- function(x){
 #' }
 #'
 #' @import dplyr stringr
-#' @importFrom magrittr %>%
 #' @importFrom rlang .data
 #' @export
 as_any_symbol <- function(x){
@@ -691,7 +694,6 @@ as_any_symbol <- function(x){
 #' }
 #'
 #' @import dplyr tidyr stringr
-#' @importFrom magrittr %>%
 #' @importFrom rlang .data
 #' @export
 collect_roxygen <- function(folder_r = "R"){
